documentationtools.Pipe
=======================

.. abjad-lineage:: abjad.tools.documentationtools.Pipe.Pipe.Pipe

.. autoclass:: abjad.tools.documentationtools.Pipe.Pipe.Pipe
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.arguments
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.executable
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.storage_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.timeout
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.close
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.communicate
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.kill
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.poll
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.read
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.read_wait
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.send_signal
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.terminate
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.wait
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.write
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.write_line
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__del__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.Pipe.__repr__
   :noindex:
